@@ -1,4 +1,4 @@
-from PySide2.QtWidgets import *
+from qtpy.QtWidgets import *
 
 from CIDAN.GUI.Inputs.Input import Input
 
@@ -40,7 +40,10 @@ class Int3DInput(Input):
         self.input_box_3.valueChanged.connect(self.on_change)
 
     def current_state(self):
-        return self.input_box_1.value()
+        return [self.input_box_1.value(), self.input_box_2.value(),
+                self.input_box_3.value()]
 
     def set_default_val(self):
         self.input_box_1.setValue(self.default_val)
+        self.input_box_2.setValue(self.default_val)
+        self.input_box_3.setValue(self.default_val)
