@@ -1,6 +1,6 @@
 import numpy as np
 
-from CIDAN.TimeTrace.waveletDenoise import waveletDenoise
+from CIDAN.TimeTrace.mean import calculateMeanTrace
 
 
 def calculateDeltaFOverF(roi, data, denoise=True):
@@ -18,13 +18,12 @@ def calculateDeltaFOverF(roi, data, denoise=True):
     -------
     A 1d nd array with the time trace for the ROI
     """
-    pixels_in_roi = data[roi]
-    pixel_sum = np.sum(pixels_in_roi, axis=1)
-    bottom_10_number = np.percentile(pixel_sum, 10)
-    bottom_10_pixels = pixels_in_roi[pixel_sum < bottom_10_number]
-    bottom_10_avg = np.mean(bottom_10_pixels, axis=0)
-    mean = np.mean(pixels_in_roi, axis=0)
-    if denoise:
-        denoised_mean = waveletDenoise(mean.reshape((1, -1)))
-        mean = denoised_mean.reshape((-1))
-    return (mean - bottom_10_avg) / bottom_10_avg
+    time_trace = calculateMeanTrace(roi, data, denoise)
+    bottom_10_number = np.percentile(time_trace, 10)
+
+    bottom_10_frames = time_trace[time_trace < bottom_10_number]
+    bottom_10_avg = np.mean(bottom_10_frames)
+
+    if bottom_10_avg == 0:
+        return time_trace
+    return (time_trace - bottom_10_avg) / bottom_10_avg
