@@ -1,7 +1,9 @@
 import numpy as np
 
+from CIDAN.TimeTrace.waveletDenoise import waveletDenoise
 
-def calculateMeanTrace(roi, data):
+
+def calculateMeanTrace(roi, data, denoise=True):
     """
     Calcualtes the mean time trace for a given roi and data
     Parameters
@@ -13,4 +15,6 @@ def calculateMeanTrace(roi, data):
     -------
     A 1d nd array with the time trace for the ROI
     """
+    if denoise:
+        return waveletDenoise(np.mean(data[roi], axis=0).reshape((1, -1))).reshape((-1))
     return np.mean(data[roi], axis=0)
